"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const inquirer_1 = __importDefault(require("inquirer"));
const questions = [
    {
        name: 'name',
        message: 'What is the name for your app?',
        type: 'input',
        validate: (name) => /^[a-z0-9-]+$/.test(name) ? true : 'Only use lowercase alphanumeric and -'
    },
    {
        name: 'auth',
        message: 'Which Auth Provider would you like to use?',
        type: 'list',
        default: 'jwt',
        choices: [
            { value: 'firebase', name: 'Firebase' },
            // Future options: Auth0
            { value: 'jwt', name: 'JSON web token' },
            { value: 'none', name: 'None' },
        ],
    },
    {
        name: 'jwt_auth_secret',
        message: 'Please provide an auth secret for JSON webtoken',
        type: 'input',
        validate: (secret) => secret.length > 0 ? true : false,
        default: Math.random().toString(36).replace(/[^a-zA-Z0-9]+/g, '').substring(0, 16),
        when: answers => answers.auth === 'jwt'
    },
    {
        name: 'firebase_config',
        message: 'Please provide Firebase Config (https://firebase.google.com/docs/web/learn-more#config-object)',
        type: 'editor',
        validate: (json) => {
            console.log('json', json);
            try {
                const key = new Function("return " + json)();
                return Boolean(key.apiKey && key.authDomain && key.databaseURL && key.projectId && key.storageBucket && key.messagingSenderId && key.appId && key.measurementId) || 'Not a valid firebase config';
            }
            catch (e) {
                return 'Not a valid json file';
            }
        },
        when: answers => answers.auth === 'firebase'
    },
    {
        name: 'firebase_admin_token',
        message: 'Please provide Firebase Admin private key (https://firebase.google.com/docs/admin/setup#initialize-sdk)',
        type: 'editor',
        validate: (json) => {
            try {
                const key = JSON.parse(json);
                return Boolean(key.project_id && key.private_key_id && key.private_key && key.client_email && key.client_id && key.auth_uri && key.token_uri && key.auth_provider_x509_cert_url && key.client_x509_cert_url) || 'Not a valid private key';
            }
            catch (e) {
                return 'Not a valid json file';
            }
        },
        when: answers => answers.auth === 'firebase'
    },
    {
        name: 'database',
        message: 'Which database would you like to use?',
        type: 'list',
        default: 'mongodb',
        choices: [
            { value: 'mongodb', name: 'MongoDB' },
            // Future options: PostgreSQL
            { value: 'none', name: 'None' },
        ],
    },
    {
        name: 'mongo_db_url',
        message: 'Please provide your MongoDB URL for local development',
        type: 'input',
        default: 'mongodb://127.0.0.1:27017',
        validate: (url) => {
            // TODO: attempt to connect...
            return true;
        },
        when: answers => answers.database === 'mongodb'
    },
    {
        name: 'mongo_db_name',
        message: 'Please provide your MongoDB database name',
        type: 'input',
        default: (answers) => answers.name,
        validate: (name) => {
            // TODO: attempt to connect...
            return true;
        },
        when: answers => answers.database === 'mongodb'
    },
    {
        name: 'orm',
        message: 'Would you like to use an ORM?',
        type: 'list',
        default: 'no',
        choices: [
            { value: 'no', name: 'No' },
            { value: 'mikrorm', name: 'MikrORM' }
        ],
        when: answers => ['mongodb'].indexOf(answers.database) >= 0
    },
    {
        name: 'options',
        message: 'Select additions...',
        type: 'checkbox',
        default: ['express', 'gql', 'mongodb', 'router', 'mui', 'vercel', 'jotai', 'i18n'],
        choices: [
            { value: 'express', name: 'Express', short: 'express' },
            { value: 'gql', name: 'GraphQL (Apollo Server/Client)', short: 'graphql' },
            new inquirer_1.default.Separator('--- Front-end options ---'),
            { value: 'router', name: 'React Router', short: 'react-router' },
            { value: 'mui', name: 'Material UI (mui)', short: 'mui' },
            { value: 'jotai', name: 'Jotai (state management)', short: 'jotai' },
            { value: 'i18n', name: 'i18next (for translation)', short: 'i18next' },
            new inquirer_1.default.Separator('--- Hosting ---'),
            { value: 'vercel', name: 'Vercel', short: 'vercel' }
        ],
        loop: false
    },
    {
        name: 'port',
        message: 'Which port do you want the server to run on',
        type: 'number',
        default: 3001,
    }
];
exports.default = questions;
//# sourceMappingURL=questions.js.map